(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96808,       2735]*)
(*NotebookOutlinePosition[     97461,       2758]*)
(*  CellTagsIndexPosition[     97417,       2754]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
    \(\[IndentingNewLine] (*\ 
      Program\ by\ C . J . \ Hepburn\ \ \(16/03\)/2001\ *) \  (*\ 
      Calculates\ the\ energy\ levels\ in\ a\ quantum\ well\ of\ width\ w\ \
and\ depth\ V0\ with\ effective\ masses\ of\ mb\ and\ mw\ in\ the\ cladding\ \
and\ well\ layers\ \(\(respectively\)\(.\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
      GaAs\ example\ *) \[IndentingNewLine]$TextStyle = {FontFamily \[Rule] "\
\<Arial\>", FontSize \[Rule] 12}\), "\[IndentingNewLine]", 
    \(\(eV = 1.60217732999999995`*^-19;\) (*\ eV\ in\ J\ *) \), "\n", 
    \(\(meV = 
        eV/1000;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  (*\ meV\ in\ J\ *) \ \), "\n", 
    \(\(h = 6.62607549999999889`*^-34;\)\ \  (*\ 
      Planck\ constant\ J/s\ *) \), "\n", 
    \(\(hb = 
        h/\((2\ \[Pi])\);\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ hbar\ in\ eV\ *) \), "\n", 
    \(\(m0 = 9.10938969999999947`*^-31;\) (*\ 
      electron\ mass\ in\ kg*) \), "\n", 
    \(\(c = 2.99792458000000117`*^8;\)\ \ \ \ \ \ \  (*\ 
      speed\ of\ light\ in\ m/s*) \), "\n", 
    \(\(\[Epsilon]0 = \ 8.8542*^-12;\)\ \ \ \[IndentingNewLine] (*\ 
      Al\ alloy\ fraction\ *) \ \ \ \), "\[IndentingNewLine]", 
    \(\(conc = 0.3;\)\[IndentingNewLine] (*\ 
      formulae\ for\ masses\ in\ various\ bands\ \((not\ necessary\ in\ this\ \
example)\)\ *) \), "\[IndentingNewLine]", 
    \(\(me = \((0.0665 + 0.0835\ conc)\)\ m0;\)\), "\[IndentingNewLine]", 
    \(\(mhh = \((0.34 + 0.42\ conc)\) m0;\)\), "\[IndentingNewLine]", 
    \(\(mlh = \((0.094 + 0.043\ conc)\) m0;\)\), "\[IndentingNewLine]", 
    \(\(Eg = 1.424 + 1.247\ conc\ \ \ eV;\)\[IndentingNewLine] (*\ 
      GaAs\ parameters\ *) \[IndentingNewLine] (*\ 
      mass\ in\ well\ *) \), "\[IndentingNewLine]", 
    \("\<mw\>"\), "\[IndentingNewLine]", 
    \(mw = 0.0665  m0\ \[IndentingNewLine] (*\ 
      mass\ in\ barrier\ *) \), "\[IndentingNewLine]", 
    \("\<mb\>"\), "\[IndentingNewLine]", 
    \(mb = me\[IndentingNewLine] (*\ 
      potential\ well\ depth\ *) \), "\[IndentingNewLine]", 
    \("\<V0\>"\), "\[IndentingNewLine]", 
    \(V0 = \ 250.6  meV\ \[IndentingNewLine] (*\ 
      width\ of\ well\ *) \), "\[IndentingNewLine]", 
    \("\<Lw\>"\), "\[IndentingNewLine]", 
    \(lw = 100\ 10\^\(-10\)\[IndentingNewLine] (*\ 
      radius\ where\ solutions\ to\ be\ found\ *) \), "\[IndentingNewLine]", 
    \("\<r\>"\), "\[IndentingNewLine]", 
    \(r[x_] := \@\(\((\(2\ mw\ V0\)\/hb\^2\ \((lw\/2)\)\^2 - x\^2)\)\(\
\[IndentingNewLine]\)\)\), "\[IndentingNewLine]", 
    \(\(mr = mb/mw;\)\), "\n", 
    \(\ \(Plot[{\@mr\ x\ Tan[x], \(-\@mr\)\ x\ \ Cot[x], r[x]}, {x, 0, r[0]}, 
        PlotStyle \[Rule] {Hue[0.6], Hue[0.6], Hue[0]}, 
        PlotRange \[Rule] {{0, r[0]}, {\(-2\), 4}}, 
        AspectRatio \[Rule] GoldenSection, 
        AxesLabel \[Rule] {\*"\"\<k \!\(L\/2\)\>\"", \*"\"\<\!\(\@\(2\\\\\\\\\
\\\\\\\ m\_w\\\\\\\\\\\\\\\ \(\(V\_0\) \((L/2\\\\\\\\\\\\\\\ \[HBar])\)\)\)\)\
\>\""}];\)\), "\[IndentingNewLine]", 
    \(\(oddsol = 
        Flatten[Table[
            FindRoot[\ \(\@mr\) x\ Tan[x] - r[x] \[Equal] 0, {x, 
                i + 0.5}], {i, 1, 
              Floor[\(\(\@\(2  mw\ V0\)\) lw\/\(2  \
hb\)\)\/\(\[Pi]\/2\)]}]];\)\), "\[IndentingNewLine]", 
    \(\(evensol = 
        Flatten[Table[
            FindRoot[\(-\@mr\)\ x\ Cot[x] - r[x] \[Equal] 0, {x, 
                i + 1.5}], {i, 1, 
              Floor[\(\(\@\(2  mw\ V0\)\) lw\/\(2  \
hb\)\)\/\(\[Pi]\/2\)]}]];\)\), "\[IndentingNewLine]", 
    \(\(oddsol = 
        Table[Abs[oddsol[\([i, 2]\)]], {i, 1, 
            Length[oddsol]}];\)\), "\[IndentingNewLine]", 
    \(\(evensol = 
        Table[Abs[evensol[\([i, 2]\)]], {i, 1, 
            Length[evensol]}];\)\), "\[IndentingNewLine]", 
    \(allsol = Sort[Flatten[{oddsol, evensol}]]\), "\[IndentingNewLine]", 
    \(\(energies = 
        Map[\((\(\(2  #\^2\ hb\^2\)\/\(mw*\ lw\^2\)\)/meV)\) &, 
          allsol];\)\), "\[IndentingNewLine]", 
    \(\(w = lw*10^10;\)\[IndentingNewLine] (*\ 
      points\ defining\ the\ well\ *) \), "\[IndentingNewLine]", 
    \(\(well = {{0, V0/meV}, {w, V0/meV}, {w, 0}, {2  w, 0}, {2  w, 
            V0/meV}, {3  w, 
            V0/meV}};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(eng[
          i_] := {{w, energies[\([i]\)]}, {2\ w, 
            energies[\([i]\)]}};\)\), "\[IndentingNewLine]", 
    \(\(well = 
        Graphics[
          ListPlot[well, 
            PlotJoined \[Rule] True]];\)\), "\[IndentingNewLine]", 
    \(\(Show[{well, 
          Table[Graphics[Line[Partition[Flatten[eng[i]], 2]]], {i, 
              Length[energies] - 1}], 
          Table[Graphics[
              Text[NumberForm[energies[\([i]\)] "\< meV\>", {7, 2}], {2.5  w, 
                  energies[\([i]\)]}]], {i, Length[energies] - 1}]}, 
        Axes \[Rule] False];\)\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{FontFamily \[Rule] "Arial", 
      FontSize \[Rule] 12}\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"mw"\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`6.0577441505`*^-32\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"mb"\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`8.33964627035`*^-32\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"V0"\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`4.01505638898`*^-20\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"Lw"\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`1\/100000000\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"r"\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{\(AspectRatio::"aspr"\), \(\(:\)\(\ \)\), "\<\"Value of option \
AspectRatio -> \\!\\(TraditionalForm\\`GoldenSection\\) is not a finite \
positive number or Automatic.\"\>"}], TraditionalForm]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.81444 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.302406 0.604812 0.302406 [
[.1512 .59231 -10.25 -15.3125 ]
[.1512 .59231 10.25 0 ]
[.30241 .59231 -5.28125 -15.3125 ]
[.30241 .59231 5.28125 0 ]
[.45361 .59231 -10.25 -15.3125 ]
[.45361 .59231 10.25 0 ]
[.60481 .59231 -5.28125 -15.3125 ]
[.60481 .59231 5.28125 0 ]
[.75601 .59231 -10.25 -15.3125 ]
[.75601 .59231 10.25 0 ]
[.90722 .59231 -5.28125 -15.3125 ]
[.90722 .59231 5.28125 0 ]
[1.025 .60481 0 -13.5 ]
[1.025 .60481 26.25 13.5 ]
[-0.0125 0 -18.875 -7.65625 ]
[-0.0125 0 0 7.65625 ]
[-0.0125 .30241 -18.875 -7.65625 ]
[-0.0125 .30241 0 7.65625 ]
[-0.0125 .90722 -10.5625 -7.65625 ]
[-0.0125 .90722 0 7.65625 ]
[-0.0125 1.20962 -10.5625 -7.65625 ]
[-0.0125 1.20962 0 7.65625 ]
[-0.0125 1.51203 -10.5625 -7.65625 ]
[-0.0125 1.51203 0 7.65625 ]
[-0.0125 1.81444 -10.5625 -7.65625 ]
[-0.0125 1.81444 0 7.65625 ]
[0 1.83944 -58.125 0 ]
[0 1.83944 58.125 16.625 ]
[ 0 0 0 0 ]
[ 1 1.81444 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1512 .60481 m
.1512 .61106 L
s
gsave
.1512 .59231 -71.25 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.30241 .60481 m
.30241 .61106 L
s
gsave
.30241 .59231 -66.2813 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.45361 .60481 m
.45361 .61106 L
s
gsave
.45361 .59231 -71.25 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.60481 .60481 m
.60481 .61106 L
s
gsave
.60481 .59231 -66.2813 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.75601 .60481 m
.75601 .61106 L
s
gsave
.75601 .59231 -71.25 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.90722 .60481 m
.90722 .61106 L
s
gsave
.90722 .59231 -66.2813 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.03024 .60481 m
.03024 .60856 L
s
.06048 .60481 m
.06048 .60856 L
s
.09072 .60481 m
.09072 .60856 L
s
.12096 .60481 m
.12096 .60856 L
s
.18144 .60481 m
.18144 .60856 L
s
.21168 .60481 m
.21168 .60856 L
s
.24192 .60481 m
.24192 .60856 L
s
.27217 .60481 m
.27217 .60856 L
s
.33265 .60481 m
.33265 .60856 L
s
.36289 .60481 m
.36289 .60856 L
s
.39313 .60481 m
.39313 .60856 L
s
.42337 .60481 m
.42337 .60856 L
s
.48385 .60481 m
.48385 .60856 L
s
.51409 .60481 m
.51409 .60856 L
s
.54433 .60481 m
.54433 .60856 L
s
.57457 .60481 m
.57457 .60856 L
s
.63505 .60481 m
.63505 .60856 L
s
.66529 .60481 m
.66529 .60856 L
s
.69553 .60481 m
.69553 .60856 L
s
.72577 .60481 m
.72577 .60856 L
s
.78626 .60481 m
.78626 .60856 L
s
.8165 .60481 m
.8165 .60856 L
s
.84674 .60481 m
.84674 .60856 L
s
.87698 .60481 m
.87698 .60856 L
s
.93746 .60481 m
.93746 .60856 L
s
.9677 .60481 m
.9677 .60856 L
s
.99794 .60481 m
.99794 .60856 L
s
.25 Mabswid
0 .60481 m
1 .60481 L
s
gsave
1.025 .60481 -61 -17.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 35 translate 1 -1 scale
63.000 21.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 21.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.625 13.563 moveto
(L) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.313 21.500 moveto
(\\200\\200\\200\\200) show
81.500 21.500 moveto
(\\200) show
75.625 30.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
85.250 21.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
gsave
-0.0125 0 -79.875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.313 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .30241 m
.00625 .30241 L
s
gsave
-0.0125 .30241 -79.875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.313 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .90722 m
.00625 .90722 L
s
gsave
-0.0125 .90722 -71.5625 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 1.20962 m
.00625 1.20962 L
s
gsave
-0.0125 1.20962 -71.5625 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 1.51203 m
.00625 1.51203 L
s
gsave
-0.0125 1.51203 -71.5625 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 1.81444 m
.00625 1.81444 L
s
gsave
-0.0125 1.81444 -71.5625 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06048 m
.00375 .06048 L
s
0 .12096 m
.00375 .12096 L
s
0 .18144 m
.00375 .18144 L
s
0 .24192 m
.00375 .24192 L
s
0 .36289 m
.00375 .36289 L
s
0 .42337 m
.00375 .42337 L
s
0 .48385 m
.00375 .48385 L
s
0 .54433 m
.00375 .54433 L
s
0 .66529 m
.00375 .66529 L
s
0 .72577 m
.00375 .72577 L
s
0 .78626 m
.00375 .78626 L
s
0 .84674 m
.00375 .84674 L
s
0 .9677 m
.00375 .9677 L
s
0 1.02818 m
.00375 1.02818 L
s
0 1.08866 m
.00375 1.08866 L
s
0 1.14914 m
.00375 1.14914 L
s
0 1.2701 m
.00375 1.2701 L
s
0 1.33059 m
.00375 1.33059 L
s
0 1.39107 m
.00375 1.39107 L
s
0 1.45155 m
.00375 1.45155 L
s
0 1.57251 m
.00375 1.57251 L
s
0 1.63299 m
.00375 1.63299 L
s
0 1.69347 m
.00375 1.69347 L
s
0 1.75395 m
.00375 1.75395 L
s
.25 Mabswid
0 0 m
0 1.81444 L
s
gsave
0 1.83944 -119.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.625 translate 1 -1 scale
63.000 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 9.813 moveto
(\\217) show
72.938 9.813 moveto
(!) show
75.375 9.813 moveto
(!) show
77.813 9.813 moveto
(!) show
80.250 9.813 moveto
(!) show
82.688 9.813 moveto
(!) show
85.125 9.813 moveto
(!) show
87.563 9.813 moveto
(!) show
90.000 9.813 moveto
(!) show
92.438 9.813 moveto
(!) show
94.875 9.813 moveto
(!) show
97.313 9.813 moveto
(!) show
99.750 9.813 moveto
(!) show
102.188 9.813 moveto
(!) show
104.625 9.813 moveto
(!) show
107.063 9.813 moveto
(!) show
109.500 9.813 moveto
(!) show
111.938 9.813 moveto
(!) show
114.375 9.813 moveto
(!) show
116.813 9.813 moveto
(!) show
119.250 9.813 moveto
(!) show
121.688 9.813 moveto
(!) show
124.125 9.813 moveto
(!) show
126.563 9.813 moveto
(!) show
129.000 9.813 moveto
(!) show
131.438 9.813 moveto
(!) show
133.875 9.813 moveto
(!) show
136.313 9.813 moveto
(!) show
138.750 9.813 moveto
(!) show
141.188 9.813 moveto
(!) show
143.625 9.813 moveto
(!) show
146.063 9.813 moveto
(!) show
148.500 9.813 moveto
(!) show
150.938 9.813 moveto
(!) show
153.375 9.813 moveto
(!) show
155.813 9.813 moveto
(!) show
158.250 9.813 moveto
(!) show
160.688 9.813 moveto
(!) show
163.125 9.813 moveto
(!) show
165.563 9.813 moveto
(!) show
168.000 9.813 moveto
(!) show
170.438 9.813 moveto
(!) show
172.000 9.813 moveto
(!) show
73.375 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.688 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\\\) show
89.000 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
98.938 18.938 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
107.188 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\\\) show
114.500 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
122.500 19.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
127.750 17.063 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.938 17.063 moveto
(H) show
133.688 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
142.000 17.063 moveto
(\\220) show
147.500 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
155.813 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\\\) show
163.125 17.063 moveto
%%IncludeResource: font Math3
%%IncludeFont: Math3
/Math3 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\321) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
169.313 17.063 moveto
(L) show
175.250 17.063 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.81444 L
0 1.81444 L
closepath
clip
newpath
0 .4 1 r
.5 Mabswid
0 .60481 m
.00123 .60482 L
.00236 .60483 L
.00365 .60486 L
.00488 .6049 L
.00706 .60501 L
.00942 .60516 L
.01203 .60537 L
.01479 .60566 L
.01975 .60633 L
.02486 .60722 L
.02966 .60823 L
.04057 .61124 L
.0517 .61528 L
.06188 .61988 L
.08481 .63347 L
.10474 .64917 L
.1265 .6708 L
.14889 .69852 L
.16918 .72911 L
.21027 .81064 L
.23048 .86294 L
.25234 .93144 L
.27286 1.01017 L
.29539 1.118 L
.31683 1.24946 L
.33685 1.40882 L
.35822 1.63841 L
s
.35822 1.63841 m
.36982 1.81444 L
s
.47626 1.81444 m
.47626 0 L
s
.77243 0 m
.78569 .04786 L
.82787 .18955 L
.86845 .32305 L
.91162 .46819 L
.95319 .61647 L
.99317 .77216 L
1 .80045 L
s
0 .24999 m
.00123 .24999 L
.00236 .25 L
.00365 .25001 L
.00488 .25002 L
.00706 .25006 L
.00942 .25011 L
.01203 .25018 L
.01479 .25027 L
.01975 .2505 L
.02486 .25079 L
.02966 .25113 L
.04057 .25212 L
.0517 .25345 L
.06188 .25496 L
.08481 .25934 L
.10474 .2643 L
.1265 .27093 L
.16918 .28781 L
.21027 .3091 L
.25393 .33759 L
.296 .37127 L
.33648 .41013 L
.37953 .45933 L
.42099 .51561 L
.46086 .57948 L
.50331 .66022 L
.54416 .75339 L
.58759 .87401 L
.62943 1.0185 L
.66967 1.19435 L
.7125 1.44062 L
.73376 1.59601 L
.75372 1.77015 L
s
.75372 1.77015 m
.75793 1.81444 L
s
.9491 1.81444 m
.9491 0 L
s
1 0 0 r
0 1.60481 m
.00123 1.60481 L
.00236 1.60481 L
.00365 1.60481 L
.00488 1.6048 L
.00706 1.60479 L
.00942 1.60477 L
.01203 1.60474 L
.01479 1.6047 L
.01975 1.60462 L
.02486 1.6045 L
.02966 1.60437 L
.04057 1.60399 L
.0517 1.60347 L
.06188 1.6029 L
.08481 1.60121 L
.10474 1.59931 L
.1265 1.59678 L
.16918 1.5904 L
.21027 1.58246 L
.25393 1.57203 L
.296 1.56 L
.33648 1.5465 L
.37953 1.52999 L
.42099 1.51188 L
.46086 1.49228 L
.50331 1.46892 L
.54416 1.44379 L
.58759 1.41397 L
.62943 1.38187 L
.66967 1.34747 L
.7125 1.30649 L
.75372 1.262 L
.79336 1.21356 L
.83558 1.15419 L
.8762 1.08676 L
.91939 .99815 L
.94095 .94336 L
.961 .88136 L
.9707 .84511 L
.97986 .80452 L
.98492 .77782 L
.99041 .74297 L
.99283 .72432 L
.9954 .70062 L
.99759 .67419 L
.99884 .65306 L
1 .6051 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{158.688, 287.875},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002N00017aP00`40o`000?l0003oW_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_oo
o`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00W_ooo`00<Oooo`D0001X
oooo000boooo00<0003oooooool0JOooo`00<oooo`030000oooooooo06Soool002Woool700001?oo
o`030000oooooooo00?oool00`000?ooooooo`0Ooooo00<0I_ooooooool04_ooo`0306Kooooooooo
00[oool00`1Vooooooooo`0Moooo000doooo00<0003oooooool00oooo`030000oooooooo01ooool0
0`1Vooooooooo`0Boooo00<0I_ooooooool02_ooo`0306Kooooooooo01goool003Goool00`000?oo
ooooo`02oooo00<0003oooooool07oooo`0306Kooooooooo01?oool00`1Vooooooooo`09oooo00<0
I_ooooooool07Oooo`00=Oooo`030000oooooooo00;oool00`000?ooooooo`0Ooooo00<0I_oooooo
ool04oooo`0306Kooooooooo00Woool00`1Vooooooooo`0Moooo000aoooo00D0003oooooooooool0
00001?ooo`030000oooooooo01ooool00`1Vooooooooo`0Coooo00<0I_ooooooool02Oooo`0306Ko
oooooooo01goool003;oool300001Oooo`030000oooooooo01ooool00`1Vooooooooo`0Doooo00<0
I_ooooooool02?ooo`0306Kooooooooo01goool003[oool00`000?ooooooo`0Ooooo00<0I_oooooo
ool05?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0Moooo000joooo00<0003oooooool07ooo
o`0306Kooooooooo01Coool00`1Vooooooooo`08oooo00<0I_ooooooool07Oooo`00>_ooo`030000
oooooooo01ooool00`1Vooooooooo`0Eoooo00<0I_ooooooool01oooo`0306Kooooooooo01goool0
03[oool00`000?ooooooo`0Ooooo00<0I_ooooooool05Oooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0Moooo000joooo00<0003oooooool07oooo`0306Kooooooooo01Goool00`1Vooooooooo`07
oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01ooool00`1Vooooooooo`0Eoooo00<0
I_ooooooool01oooo`0306Kooooooooo01goool003[oool00`000?ooooooo`0Ooooo00<0I_oooooo
ool05_ooo`0306Kooooooooo00Koool00`1Vooooooooo`0Moooo000joooo00<0003oooooool07ooo
o`0306Kooooooooo01Koool00`1Vooooooooo`06oooo00<0I_ooooooool07Oooo`00>_ooo`030000
oooooooo01ooool00`1Vooooooooo`0Foooo00<0I_ooooooool01_ooo`0306Kooooooooo01goool0
03[oool00`000?ooooooo`0Ooooo00<0I_ooooooool05oooo`0306Kooooooooo00Goool00`1Voooo
ooooo`0Moooo000joooo00<0003oooooool07oooo`0306Kooooooooo01Ooool00`1Vooooooooo`05
oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01ooool00`1Vooooooooo`0Goooo00<0
I_ooooooool01Oooo`0306Kooooooooo01goool003?oool00`000?ooooooo`04oooo1`1Voa_oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool01?ooo`0306Kooooooooo01goool003?oool00`000?oo
ooooo`04oooo00<0003oooooool01?ooo`@0I_lGoooo00<0I_ooooooool06?ooo`0306Kooooooooo
00Coool00`1Vooooooooo`0Moooo000coooo00<0003oooooool01?ooo`030000oooooooo00Soool2
06Ko5Oooo`0306Kooooooooo01Soool00`1Vooooooooo`04oooo00<0I_ooooooool07Oooo`00:Ooo
o`L00003oooo00<0003oooooool01?ooo`030000oooooooo00[oool206Ko4oooo`0306Kooooooooo
01Soool00`1Vooooooooo`04oooo00<0I_ooooooool07Oooo`00<oooo`030000oooooooo00Coool0
0`000?ooooooo`0<oooo00<0I_ooooooool04?ooo`0306Kooooooooo01Woool00`1Vooooooooo`03
oooo00<0I_ooooooool07Oooo`00<oooo`030000oooooooo00Coool00`000?ooooooo`0=oooo0P1V
oa3oool00`1Vooooooooo`0Ioooo00<0I_ooooooool00oooo`0306Kooooooooo01goool0037oool0
0`000?ooo`000006oooo00<0003oooooool03oooo`0306Kooooooooo00goool00`1Vooooooooo`0I
oooo00<0I_ooooooool00oooo`0306Kooooooooo01goool003;oool200001_ooo`030000oooooooo
013oool206Ko3Oooo`0306Kooooooooo01[oool00`1Vooooooooo`02oooo00<0I_ooooooool07Ooo
o`00<oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo00<0I_ooooooool02_ooo`0306Ko
oooooooo01[oool00`1Vooooooooo`02oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo
01?oool00`1Vooooooooo`09oooo00<0I_ooooooool06_ooo`0306Kooooooooo00;oool00`1Voooo
ooooo`0Moooo000joooo00<0003oooooool05?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0K
oooo00D0I_ooooooooooool0I_l07oooo`00>_ooo`030000oooooooo01Goool00`1Vooooooooo`07
oooo00<0I_ooooooool06oooo`0506Kooooooooooooo06Ko01ooool003[oool00`000?ooooooo`0F
oooo00<0I_ooooooool01_ooo`0306Kooooooooo01_oool01@1Vooooooooooooo`1Vo`0Ooooo000j
oooo00@0003oooooooooool300000oooo`040000oooooooooooo0`0000Coool00`000?ooooooo`02
oooo00<0I_l0003oool00oooo`040000oooo06Kooooo0`0000;oool:00000_ooo`040000oooooooo
oooo0`0000?oool00`00001Vo`000002oooo00<0I_ooooooool07Oooo`00>_ooo`040000oooooooo
00000oooo`030000oooooooo00?oool01@000?ooooooooooo`000003oooo00<0003oooooool00_oo
o`0306Ko0000oooo00Goool00`1Vo`000?ooo`02oooo00@0003oooooool00004oooo00<0003ooooo
ool01_ooo`070000oooooooooooo0000oooo000000;oool0101Vo`000?ooo`1VoaCoool500001_oo
o`00>_ooo`040000oooooooo00000oooo`030000oooooooo00Ooool01@000?ooooooooooo`000005
oooo00<0I_ooooooool01?ooo`0306Kooooooooo00;oool01@000?ooooooooooo`000004oooo00<0
003oooooool02Oooo`030000oooooooo00;oool0101Vo`000?ooo`1VoaGoool00`000?ooooooo`07
oooo000joooo00@0003oooooool00003oooo00<0003oooooool01oooo`050000oooooooooooo0000
00Goool00`00001Vooooo`04oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo00<0003oooooool02?ooo`030000oooooooo00;oool0101Vo`000?ooo`1VoaKoool0
0`000?ooooooo`06oooo000joooo00@0003oooooool00003oooo00<0003oooooool00oooo`050000
oooooooooooo000000?oool00`000?ooooooo`03oooo00<0003oool0I_l01?ooo`0306Ko0000oooo
00;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00Coool01@000?oo
ooooooooo`000003oooo0P00000306Kooooo06Ko01Ooool00`000?ooooooo`05oooo000joooo00@0
003oooooool00003oooo00<0003oooooool00oooo`@00004oooo00<0003oooooool00oooo`030000
oooo06Ko00Coool00`1Vo`000000000200001_ooo`030000oooooooo00;oool00`000?ooooooo`03
oooo100000Koool00`1Vooooo`1Vo`0Goooo00<0003oooooool01Oooo`00>_ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oool000000oooo`030000
oooo000000;oool01P1Vooooooooooooo`1Vo`0000Woool00`000?ooooooo`02oooo00<0003ooooo
ool00oooo`030000oooooooo00Ooool00`1Vooooo`1Vo`0Hoooo00<0003oooooool01?ooo`00>_oo
o`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`03oooo0P0000Coool2
00000oooo`0606Kooooooooo06Kooooo00001?ooo`040000oooooooooooo0P0000?oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`070000oooooooooooo06Kooooo06Ko01Soool00`000?oo
ooooo`04oooo000joooo00@0003oooooooooool300001oooo`@00003oooo00<0003oooooool00ooo
o`030000oooooooo00;oool0101Vooooo`1Vooooo`@00002oooo0`0000;oool300001oooo`@00002
oooo0`000003oooo06Ko06Ko01Coool01@000?ooooooooooo`000006oooo000joooo00<0003ooooo
ool07Oooo`0306Kooooo06Ko023oool206Ko1oooo`050000oooooooooooo000000Woool300001ooo
o`00>_ooo`030000oooooooo01koool206Ko8?ooo`80I_l7oooo00@0003oooooool0000Doooo000j
oooo00<0003oooooool07oooo`0306Kooooooooo01koool206Ko1oooo`040000oooooooo00005?oo
o`00>_ooo`<0I_lO000000<0I_l0000000007`00000406Ko00000000o`001?ooo`<00007oooo2@00
00Goool003[oool00`000?ooooooo`0206Ko7Oooo`80I_lPoooo00@0I_oooooooooo0004oooo00<0
003oool000005Oooo`00>_ooo`030000oooooooo00;oool206Ko6oooo`80I_lPoooo00@0I_oooooo
oooo0004oooo00@0003oooooool0000Doooo000joooo00<0003oooooool01?ooo`0306Kooooooooo
01Soool00`1Vooooo`1Vo`0Ooooo0P1Vo`03ooooo`00oooo00?oool01@000?ooooooooooo`00000C
oooo000joooo00<0003oooooool01Oooo`0306Kooooooooo01Ooool00`1Vooooo`1Vo`0Ooooo0P1V
o`03ooooo`00oooo00?oool00`000?ooooooo`0Eoooo000joooo00<0003oooooool01_ooo`0306Ko
oooooooo01Koool00`1Vooooo`1Vo`0Ooooo0P1Vo`03ooooo`00oooo00?oool00`000?ooooooo`0:
oooo1P0000Goool003[oool00`000?ooooooo`07oooo00<0I_ooooooool05Oooo`0406Kooooooooo
06Ko7_ooo`80I_l00oooool00?ooo`0@oooo00<0003oooooool02?ooo`00>_ooo`030000oooooooo
00Ooool00`1Vooooooooo`0Eoooo00@0I_ooooooool0I_lNoooo00@0I_ooool0I_oo000Aoooo00<0
003oooooool02?ooo`00>_ooo`030000oooooooo00Soool00`1Vooooooooo`0Doooo00D0I_oooooo
ooooool0I_l07Oooo`0406Kooooo06Koo`004Oooo`030000oooooooo00Soool003[oool00`000?oo
ooooo`09oooo00<0I_ooooooool04oooo`0506Kooooooooooooo06Ko01goool0101Vooooo`1Vool0
017oool00`000?ooooooo`08oooo000joooo00<0003oooooool02_ooo`0306Kooooooooo01;oool0
0`1Vooooooooo`02oooo00<0I_ooooooool06_ooo`0306Koooooo`0001;oool00`000?ooooooo`08
oooo000joooo00<0003oooooool02_ooo`0306Kooooooooo01;oool00`1Vooooooooo`02oooo00<0
I_ooooooool06_ooo`0406Koooooo`0006Ko4Oooo`030000oooooooo00Soool003[oool00`000?oo
ooooo`0;oooo00<0I_ooooooool04Oooo`0306Kooooooooo00;oool00`1Vooooooooo`0Joooo00@0
I_oooooo0000I_lAoooo00<0003oooooool02?ooo`00>_ooo`030000oooooooo00_oool00`1Voooo
ooooo`0Aoooo00<0I_ooooooool00oooo`0306Kooooooooo01Woool0101Vooooool0001Voa7oool0
0`000?ooooooo`08oooo000joooo00<0003oooooool03?ooo`0306Kooooooooo013oool00`1Voooo
ooooo`03oooo00<0I_ooooooool06Oooo`0406Koooooo`0006Ko7?ooo`00>_ooo`030000oooooooo
00coool00`1Vooooooooo`0@oooo00<0I_ooooooool01?ooo`0306Kooooooooo01Soool00`1Voooo
ool0000Moooo000joooo00<0003oooooool03?ooo`0306Kooooooooo013oool00`1Vooooooooo`04
oooo00<0I_ooooooool06?ooo`0306Koo`00oooo01goool003[oool00`000?ooooooo`0=oooo00<0
I_ooooooool03oooo`0306Kooooooooo00Coool00`1Vooooooooo`0Hoooo00<0I_oo003oool07Ooo
o`00>_ooo`030000oooooooo00goool00`1Vooooooooo`0?oooo00<0I_ooooooool01Oooo`0306Ko
oooooooo01Ooool00`1Vool00?ooo`0Moooo000coooo00<0003oooooool01?ooo`030000oooooooo
00goool00`1Vooooooooo`0?oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00ol00?oo
ooooo`0Moooo000coooo00<0003oooooool01?ooo`030000oooooooo00koool00`1Vooooooooo`0>
oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00ol00?ooooooo`0Moooo000coooo00<0
003oooooool01?ooo`030000oooooooo00koool00`1Vooooooooo`0>oooo00<0I_ooooooool01_oo
o`0306Kooooooooo01Koool00ol00?ooooooo`0Moooo000coooo00<0003oooooool01?ooo`030000
oooooooo00ooool00`1Vooooooooo`0=oooo00<0I_ooooooool01_ooo`0306Kooooooooo01Goool0
0ol0001Vooooo`0Noooo000coooo00<0003oooooool01?ooo`030000oooooooo00ooool00`1Voooo
ooooo`0=oooo00<0I_ooooooool01_ooo`0306Kooooooooo01Goool00ol0001Vooooo`0Noooo000c
oooo00<0003oooooool01?ooo`030000oooooooo00ooool00`1Vooooooooo`0=oooo00<0I_oooooo
ool01_ooo`0306Kooooooooo01Goool00ol0001Vooooo`0Noooo000aoooo00<0003oool000001_oo
o`030000oooooooo00ooool00`1Vooooooooo`0=oooo00<0I_ooooooool01oooo`0306Kooooooooo
01?oool00ol00?ooo`1Vo`0Ooooo000boooo0P0000Koool00`000?ooooooo`0@oooo00<0I_oooooo
ool03?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Coooo00?o003oool0I_l07oooo`00<ooo
o`030000oooooooo00Coool00`000?ooooooo`0@oooo00<0I_ooooooool03?ooo`0306Kooooooooo
00Ooool00`1Vooooooooo`0Boooo00Co003oooooool0I_lOoooo000joooo00<0003oooooool04?oo
o`0306Kooooooooo00coool00`1Vooooooooo`07oooo00<0I_ooooooool04_ooo`04o`00oooooooo
06Ko7oooo`00>_ooo`030000oooooooo013oool00`1Vooooooooo`0<oooo00<0I_ooooooool02?oo
o`0306Kooooooooo017oool01?l00?ooooooo`1Voaooool003[oool00`000?ooooooo`0@oooo00<0
I_ooooooool03?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0@oooo00Go003oooooooooool0
I_l07oooo`00>_ooo`030000oooooooo017oool00`1Vooooooooo`0;oooo00<0I_ooooooool02?oo
o`0306Kooooooooo013oool01Ol00?ooooooooooo`1Vo`0Ooooo000joooo00<0003oooooool04Ooo
o`0306Kooooooooo00_oool00`1Vooooooooo`09oooo00<0I_ooooooool03_ooo`03o`00oooooooo
00;oool00`1Vooooooooo`0Moooo000joooo00<0003oooooool04Oooo`0306Kooooooooo00_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool03_ooo`03o`00oooooooo00;oool00`1Vooooooooo`0M
oooo000joooo00<0003oooooool04Oooo`0306Kooooooooo00_oool00`1Vooooooooo`09oooo00<0
I_ooooooool03Oooo`03o`00oooooooo00?oool00`1Vooooooooo`0Moooo000joooo00<0003ooooo
ool04_ooo`0306Kooooooooo00[oool00`1Vooooooooo`09oooo00<0I_ooooooool03Oooo`03o`00
oooooooo00?oool00`1Vooooooooo`0Moooo000joooo00<0003oooooool04_ooo`0306Kooooooooo
00[oool00`1Vooooooooo`0:oooo00<0I_ooooooool02oooo`03o`00oooooooo00Coool00`1Voooo
ooooo`0Moooo000joooo00<0003oooooool04_ooo`0306Kooooooooo00[oool00`1Vooooooooo`0:
oooo00<0I_ooooooool02_ooo`03o`00oooooooo00Goool00`1Vooooooooo`0Moooo000joooo00<0
003oooooool04_ooo`0306Kooooooooo00[oool00`1Vooooooooo`0:oooo00<0I_ooooooool02_oo
o`03o`00oooooooo00Goool00`1Vooooooooo`0Moooo000joooo00<0003oooooool04_ooo`0306Ko
oooooooo00[oool00`1Vooooooooo`0:oooo00<0I_ooooooool02Oooo`03o`00oooooooo00Koool0
0`1Vooooooooo`0Moooo000aoooo1@0000Coool00`000?ooooooo`0Boooo00<0I_ooooooool02_oo
o`0306Kooooooooo00_oool00`1Vooooooooo`07oooo00?o003oooooool01oooo`0306Kooooooooo
01goool003;oool00`000?ooooooo`05oooo00<0003oooooool04_ooo`0306Kooooooooo00[oool0
0`1Vooooooooo`0;oooo00<0I_ooooooool01oooo`03o`00oooooooo00Ooool00`1Vooooooooo`0M
oooo000coooo00<0003oooooool01?ooo`030000oooooooo01?oool00`1Vooooooooo`09oooo00<0
I_ooooooool02oooo`0306Kooooooooo00Koool00ol00?ooooooo`08oooo00<0I_ooooooool07Ooo
o`00=?ooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00<0I_ooooooool02Oooo`0306Ko
oooooooo00_oool00`1Vooooooooo`06oooo00?o003oooooool02?ooo`0306Kooooooooo01goool0
03Coool00`000?ooooooo`03oooo00<0003oooooool04oooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0;oooo00<0I_ooooooool01Oooo`03o`00oooooooo00Woool00`1Vooooooooo`0Moooo000e
oooo00<0003oooooool00_ooo`030000oooooooo01?oool00`1Vooooooooo`09oooo00<0I_oooooo
ool03?ooo`0306Kooooooooo00?oool00ol00?ooooooo`0:oooo00<0I_ooooooool07Oooo`00=Ooo
o`030000oooooooo00;oool00`000?ooooooo`0Coooo00<0I_ooooooool02Oooo`0306Kooooooooo
00coool00`1Vooooooooo`03oooo00?o003oooooool02_ooo`0306Kooooooooo01goool0037oool0
1@000?ooooooooooo`000004oooo00<0003oooooool04oooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool00_ooo`03o`00oooooooo00_oool00`1Vooooooooo`0Moooo000b
oooo0`0000Goool00`000?ooooooo`0Coooo00<0I_ooooooool02Oooo`0306Kooooooooo00coool0
1@1Vooooooooooooool0000>oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01Coool0
0`1Vooooooooo`08oooo00<0I_ooooooool03?ooo`0406Koooooooooo`003oooo`0306Kooooooooo
01goool003[oool00`000?ooooooo`0Doooo00<0I_ooooooool02?ooo`0306Kooooooooo00coool0
0`1Vooooool0000@oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01Coool00`1Voooo
ooooo`08oooo00<0I_ooooooool03Oooo`03o`00oooooooo00ooool00`1Vooooooooo`0Moooo000j
oooo00<0003oooooool05?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0<oooo00?o0000I_oo
ool04?ooo`0306Kooooooooo01goool003[oool00`000?ooooooo`0Doooo00<0I_ooooooool02?oo
o`0306Kooooooooo00_oool00ol00?ooo`1Vo`0Aoooo00<0I_ooooooool07Oooo`00>_ooo`030000
oooooooo01Coool00`1Vooooooooo`08oooo00<0I_ooooooool02_ooo`04o`00oooooooo06Ko4Ooo
o`0306Kooooooooo01goool003[oool00`000?ooooooo`0Eoooo00<0I_ooooooool01oooo`0306Ko
oooooooo00Woool01Ol00?ooooooooooo`1Vo`0Aoooo00<0I_ooooooool07Oooo`00>_ooo`030000
oooooooo01Goool00`1Vooooooooo`07oooo00<0I_ooooooool02?ooo`03o`00oooooooo00;oool0
0`1Vooooooooo`0?oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01Goool00`1Voooo
ooooo`07oooo00<0I_ooooooool01_ooo`;o0006oooo00<0I_ooooooool03_ooo`0306Kooooooooo
01goool003[oool00`000?ooooooo`0Eoooo00<0I_ooooooool01oooo`0306Kooooooooo00Goool0
0ol00?ooooooo`06oooo00<0I_ooooooool03_ooo`0306Kooooooooo01goool003[oool00`000?oo
ooooo`0Eoooo00<0I_ooooooool01oooo`0306Kooooooooo00?oool2o`002Oooo`0306Kooooooooo
00koool00`1Vooooooooo`0Moooo000joooo00<0003oooooool05Oooo`0306Kooooooooo00Ooool0
0`1Vooooooooo`02oooo00?o003oooooool02Oooo`0306Kooooooooo00koool00`1Vooooooooo`0M
oooo000joooo00<0003oooooool05Oooo`0306Kooooooooo00Ooool00`1Vooooooooo`02o`003?oo
o`0306Kooooooooo00koool00`1Vooooooooo`0Moooo000boooo0`0000Goool00`000?ooooooo`0E
oooo00<0I_ooooooool01oooo`0306Koooooo`0000koool00`1Vooooooooo`0>oooo00<0I_oooooo
ool07Oooo`00<Oooo`050000oooooooooooo000000Coool00`000?ooooooo`0Eoooo00<0I_oooooo
ool01oooo`;o000?oooo00<0I_ooooooool03_ooo`0306Kooooooooo01goool003Goool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`0306Kooooooooo00Goool2o`0000<0I_ooooooool03_oo
o`0306Kooooooooo00koool00`1Vooooooooo`0Moooo000eoooo00<0003oooooool00_ooo`030000
oooooooo01Goool00`1Vooooooooo`02oooo0ol000;oool00`1Vooooooooo`0>oooo00<0I_oooooo
ool03_ooo`0306Kooooooooo01goool003?oool200001Oooo`030000oooooooo01Koool0101Vool0
0?l00?l000Goool00`1Vooooooooo`0?oooo00<0I_ooooooool03Oooo`0306Kooooooooo01goool0
03Goool00`000?ooooooo`02oooo00<0003oooooool05?ooo`?o0008oooo00<0I_ooooooool03ooo
o`0306Kooooooooo00goool00`1Vooooooooo`0Moooo000eoooo00<0003oooooool00_ooo`030000
oooooooo017oool3o`000_ooo`0306Kooooooooo00Koool00`1Vooooooooo`0?oooo00<0I_oooooo
ool03Oooo`0306Kooooooooo01goool0037oool01@000?ooooooooooo`000004oooo00<0003ooooo
ool03_ooo`?o0005oooo00<0I_ooooooool01_ooo`0306Kooooooooo00ooool00`1Vooooooooo`0=
oooo00<0I_ooooooool07Oooo`00<_ooo`<00005oooo00<0003oooooool02oooo`?o0008oooo00<0
I_ooooooool01_ooo`0306Kooooooooo00ooool00`1Vooooooooo`0=oooo00<0I_ooooooool07Ooo
o`00>_ooo`030000oooooooo00_o000;oooo00<0I_ooooooool01_ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`0=oooo00<0I_ooooooool07Oooo`00>_ooo`Co000Eoooo00<0I_ooooooool01_oo
o`0306Kooooooooo00ooool00`1Vooooooooo`0=oooo00<0I_ooooooool07Oooo`00>_ooo`030000
oooooooo01Koool00`1Vooooooooo`06oooo00<0I_ooooooool03oooo`0306Kooooooooo00goool0
0`1Vooooooooo`0Moooo000joooo00<0003oooooool05_ooo`0306Kooooooooo00Koool00`1Voooo
ooooo`0@oooo00<0I_ooooooool03?ooo`0306Kooooooooo01goool003[oool00`000?ooooooo`0F
oooo00<0I_ooooooool01_ooo`0306Kooooooooo013oool00`1Vooooooooo`0<oooo00<0I_oooooo
ool07Oooo`00>_ooo`030000oooooooo01Koool00`1Vooooooooo`06oooo00<0I_ooooooool04?oo
o`0306Kooooooooo00coool00`1Vooooooooo`0Moooo000joooo00<0003oooooool05_ooo`0306Ko
oooooooo00Koool00`1Vooooooooo`0@oooo00<0I_ooooooool03?ooo`0306Kooooooooo01goool0
03[oool00`000?ooooooo`0Foooo00<0I_ooooooool01_ooo`0306Kooooooooo013oool00`1Voooo
ooooo`0<oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo01Koool00`1Vooooooooo`06
oooo00<0I_ooooooool04?ooo`0306Kooooooooo00coool00`1Vooooooooo`0Moooo000joooo00<0
003oooooool05_ooo`0306Kooooooooo00Koool00`1Vooooooooo`0Aoooo00<0I_ooooooool02ooo
o`0306Kooooooooo01goool003[oool00`000?ooooooo`0Goooo00<0I_ooooooool01Oooo`0306Ko
oooooooo017oool00`1Vooooooooo`0;oooo00<0I_ooooooool07Oooo`00>_ooo`030000oooooooo
01Ooool00`1Vooooooooo`05oooo00<0I_ooooooool04Oooo`0306Kooooooooo00_oool00`1Voooo
ooooo`0Moooo000doooo00<0003oooooool00oooo`030000oooooooo01Ooool00`1Vooooooooo`05
oooo00<0I_ooooooool04Oooo`0306Kooooooooo00_oool00`1Vooooooooo`0Moooo000doooo00<0
003oooooool00oooo`030000oooooooo01Ooool00`1Vooooooooo`05oooo00<0I_ooooooool04Ooo
o`0306Kooooooooo00_oool00`1Vooooooooo`0Moooo000aoooo1@0000Coool00`000?ooooooo`0G
oooo00<0I_ooooooool01Oooo`0306Kooooooooo017oool00`1Vooooooooo`0;oooo00<0I_oooooo
ool07Oooo`00<Oooo`040000oooooooo00001Oooo`030000oooooooo01Ooool00`1Vooooooooo`05
oooo00<0I_ooooooool04Oooo`0306Kooooooooo00_oool00`1Vooooooooo`0Moooo000boooo00<0
003oool000001Oooo`030000oooooooo01Ooool00`1Vooooooooo`05oooo00<0I_ooooooool04Ooo
o`0306Kooooooooo00_oool00`1Vooooooooo`0Moooo000boooo00<0003oool00000JOooo`00<ooo
o`80001Yoooo000coooo0P0006Woool000Ooool00`000?ooooooo`0Loooo00<0003oool000002ooo
o`030000oooooooo00Koool300001oooo`030000oooooooo00Ooool00`000?ooooooo`0Hoooo00<0
003oooooool0;oooo`001oooo`030000oooooooo01_oool01@000?ooo`000?ooo`00000Coooo00@0
003oooooool00005oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`0^
oooo0006oooo0P0000Goool500001?ooo`030000oooooooo00Coool01@000?ooooooooooo`000003
oooo00D0003oool0003oool000001_ooo`030000oooooooo00Goool00`000?ooooooo`02oooo00@0
003oooooool00004oooo00@0003oooooooooool600000oooo`030000oooooooo00;oool500001?oo
o`030000oooooooo00?oool00`000?ooooooo`0200000oooo`030000oooooooo02goool000Koool3
00001Oooo`030000oooooooo00Goool00`000?ooooooo`04oooo00D0003oooooooooool000000ooo
o`050000oooo0000oooo000000Koool00`000?ooooooo`05oooo00<0003oooooool00_ooo`040000
oooooooo00001?ooo`050000oooooooooooo000000Soool00`000?ooooooo`03oooo00<0003ooooo
ool01Oooo`030000oooooooo00Coool00`000?ooo`000004oooo00<0003oooooool0;Oooo`001Ooo
o`8000000oooo`000?ooo`05oooo00<0003oooooool00oooo`030000oooooooo00Goool01@000?oo
ooooooooo`000003oooo00D0003oool0003oool000001Oooo`030000oooooooo00Goool00`000?oo
o`000003oooo00@0003oooooool00004oooo00D0003oooooooooool000002?ooo`030000oooooooo
00Coool00`000?ooooooo`03oooo00<0003oooooool01Oooo`030000oooo000000Coool00`000?oo
ooooo`0]oooo0005oooo0P000003oooo0000oooo00Koool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`050000oooooooooooo000000?oool00`000?ooooooo`07oooo00<0003oooooool01Ooo
o`030000oooo000000?oool010000?ooooooo`0000Coool01@000?ooooooooooo`000009oooo00<0
003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0P000003oooo0000oooo
00;oool00`000?ooooooo`0]oooo0002oooo00@0003oool000000003oooo00<0003oooooool01?oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00D0003oooooooooool000000oooo`030000
oooooooo00Ooool00`000?ooooooo`04oooo00D0003oooooooooool000000oooo`800005oooo00D0
003oooooooooool000002Oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`<000000oooo`000?ooo`02oooo00<0003oooooool0;Oooo`000oooo`<00003oooo00<0
003oooooool01Oooo`050000oooooooooooo000000Ooool200000_ooo`800002oooo00<0003ooooo
ool01oooo`030000oooooooo00Coool01@000?ooooooooooo`00000:oooo00D0003oooooooooool0
00002Oooo`030000oooooooo00Goool01@000?ooooooooooo`000007oooo0`0000Coool00`000?oo
ooooo`0]oooo0009oooo00<0003oooooool01Oooo`050000oooooooooooo000000Ooool010000?oo
o`00000000;oool200002_ooo`030000oooooooo00Coool01@000?ooooooooooo`00000:oooo00D0
003oooooooooool000002Oooo`030000oooooooo00Goool01@000?ooooooooooo`000008oooo00<0
003oool000000oooo`030000oooooooo02goool000[oool010000?ooooooo`0000?oool010000?oo
ooooo`0001Woool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00Soool0
10000?ooooooo`0000[oool010000?ooooooo`0000?oool010000?ooooooo`0000Woool00`000?oo
ooooo`02oooo00<0003oooooool0;_ooo`002_ooo`040000oooooooooooo0`0000?oool00`000?oo
ooooo`0Goooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`09oooo00<0
003oool000002_ooo`040000oooooooooooo0`0000?oool00`000?ooooooo`0;oooo00<0003ooooo
ool0;oooo`002_ooo`030000oooooooo097oool000_oool00`000?ooooooo`2@oooo000:ooooJ000
02coool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool009koool009koool009koool0
09koool009koool009koool009koool009koool009koool009koool00001\
\>"],
  ImageRangeCache->{{{0, 157.688}, {286.875, 0}} -> {-2.68736, -5.38299, \
0.0462338, 0.0462338}}],

Cell[BoxData[
    FormBox[
      RowBox[{\(FindRoot::"cvnwt"\), \(\(:\)\(\ \)\), "\<\"Newton's method \
failed to converge to the prescribed accuracy after \
\\!\\(TraditionalForm\\`15\\) iterations.\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`{1.1575701804890102`, 2.294838511767268`, 
      3.2696874161569878`, 4.539141857634294`}\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.00234878 [
[.18254 .00222 -8.5625 -15.3125 ]
[.18254 .00222 8.5625 0 ]
[.34127 .00222 -11.8438 -15.3125 ]
[.34127 .00222 11.8438 0 ]
[.5 .00222 -11.8438 -15.3125 ]
[.5 .00222 11.8438 0 ]
[.65873 .00222 -11.8438 -15.3125 ]
[.65873 .00222 11.8438 0 ]
[.81746 .00222 -11.8438 -15.3125 ]
[.81746 .00222 11.8438 0 ]
[.97619 .00222 -11.8438 -15.3125 ]
[.97619 .00222 11.8438 0 ]
[.01131 .13215 -17.125 -7.65625 ]
[.01131 .13215 0 7.65625 ]
[.01131 .24959 -23.6875 -7.65625 ]
[.01131 .24959 0 7.65625 ]
[.01131 .36703 -23.6875 -7.65625 ]
[.01131 .36703 0 7.65625 ]
[.01131 .48447 -23.6875 -7.65625 ]
[.01131 .48447 0 7.65625 ]
[.01131 .60191 -23.6875 -7.65625 ]
[.01131 .60191 0 7.65625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
gsave
.18254 .00222 -69.5625 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 .01472 m
.34127 .02097 L
s
gsave
.34127 .00222 -72.8438 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -72.8438 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 .01472 m
.65873 .02097 L
s
gsave
.65873 .00222 -72.8438 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 .01472 m
.81746 .02097 L
s
gsave
.81746 .00222 -72.8438 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -72.8438 -19.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13215 m
.03006 .13215 L
s
gsave
.01131 .13215 -78.125 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.02381 .24959 m
.03006 .24959 L
s
gsave
.01131 .24959 -84.6875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.02381 .36703 m
.03006 .36703 L
s
gsave
.01131 .36703 -84.6875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.02381 .48447 m
.03006 .48447 L
s
gsave
.01131 .48447 -84.6875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.02381 .60191 m
.03006 .60191 L
s
gsave
.01131 .60191 -84.6875 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0382 m
.02756 .0382 L
s
.02381 .06169 m
.02756 .06169 L
s
.02381 .08518 m
.02756 .08518 L
s
.02381 .10867 m
.02756 .10867 L
s
.02381 .15564 m
.02756 .15564 L
s
.02381 .17913 m
.02756 .17913 L
s
.02381 .20262 m
.02756 .20262 L
s
.02381 .22611 m
.02756 .22611 L
s
.02381 .27308 m
.02756 .27308 L
s
.02381 .29657 m
.02756 .29657 L
s
.02381 .32006 m
.02756 .32006 L
s
.02381 .34354 m
.02756 .34354 L
s
.02381 .39052 m
.02756 .39052 L
s
.02381 .41401 m
.02756 .41401 L
s
.02381 .4375 m
.02756 .4375 L
s
.02381 .46098 m
.02756 .46098 L
s
.02381 .50796 m
.02756 .50796 L
s
.02381 .53145 m
.02756 .53145 L
s
.02381 .55493 m
.02756 .55493 L
s
.02381 .57842 m
.02756 .57842 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.34127 .60332 L
.34127 .01472 L
.65873 .01472 L
.65873 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool0047oool300001?ooo`<0000Loooo00<0003ooooo
ool00oooo`<00004oooo0`0001Woool00`000?ooooooo`03oooo0`0000Coool300005_ooo`D00003
oooo0`0000Coool300005oooo`D00003oooo0`0000Coool300006?ooo`<00004oooo0`0000Coool3
00001_ooo`00@?ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00000Koooo00<0
003oooooool00_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00000Hoooo00<0
003oooooool00_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00000Foooo00<0
003oooooool00oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00000Goooo00<0
003oooooool00oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00000Foooo00D0
003oooooooooool000000_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`000005
oooo0014oooo00@0003oooooool00003oooo00<0003oooooool06Oooo`030000oooooooo00;oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool000006?ooo`030000oooooooo00Koool0
10000?ooooooo`0000?oool00`000?ooooooo`0Eoooo00<0003oooooool00_ooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00000Hoooo00<0003oooooool01_ooo`040000oooooooo
00000oooo`030000oooooooo01Soool010000?ooooooo`0000?oool010000?ooooooo`0000?oool0
0`000?ooooooo`03oooo0014oooo00@0003oooooool00003oooo00<0003oooooool06Oooo`030000
oooooooo00;oool01@000?ooooooooooo`000002oooo00D0003oooooooooool000006?ooo`030000
oooooooo00Koool010000?ooooooo`0000?oool00`000?ooooooo`0Foooo00D0003oooooooooool0
00000oooo`040000oooooooo00000oooo`030000oooooooo01Ooool00`000?ooooooo`05oooo00@0
003oooooool00003oooo00<0003oooooool06?ooo`040000oooooooo00000oooo`040000oooooooo
00000oooo`030000oooooooo00?oool0043oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool000006oooo`030000oooooooo00;oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool000006?ooo`030000oooooooo00;oool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool000006?ooo`050000oooooooooooo000000?oool010000?ooooooo`0000?oool00`000?oo
ooooo`0Goooo00D0003oooooooooool000000oooo`040000oooooooo00000oooo`030000oooooooo
01Koool200000oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`000005oooo0010
oooo100000?oool01@000?ooooooooooo`00000Koooo00<0003oooooool00_ooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00000Hoooo00<0003oooooool00_ooo`@00003oooo00D0
003oooooooooool000006Oooo`040000oooooooo00000oooo`040000oooooooo00000oooo`030000
oooooooo01Soool00`000?ooooooo`0400000oooo`050000oooooooooooo000001[oool010000?oo
ooooo`0000?oool010000?ooooooo`0000?oool00`000?ooooooo`03oooo0010oooo00<0003ooooo
ool01?ooo`050000oooooooooooo000001Woool00`000?ooo`000004oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000001Koool00`000?ooo`000004oooo00<0003oooooool01?oo
o`050000oooooooooooo000001Woool010000?ooooooo`0000?oool010000?ooooooo`0000?oool0
0`000?ooooooo`0Hoooo00@0003oooooool00006oooo00D0003oooooooooool000006_ooo`040000
oooooooo00000oooo`040000oooooooo00000oooo`030000oooooooo00?oool0047oool00`000?oo
ooooo`03oooo00D0003oooooooooool000006_ooo`800004oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000001Ooool200001Oooo`030000oooooooo00?oool01@000?oooooooooo
o`00000Eoooo00D0003oooooooooool000000_ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00000Foooo00D0003oooooooooool000000oooo`030000oooooooo00?oool01@000?oo
ooooooooo`00000Foooo00D0003oooooooooool000000_ooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`000005oooo0011oooo100000?oool300007?ooo`030000oooooooo00?oool3
00001?ooo`<0000Ioooo00<0003oooooool00oooo`@00003oooo0`0001Ooool300001?ooo`<00004
oooo0`0001Soool300001?ooo`@00003oooo0`0001Soool300001?ooo`<00004oooo0`0000Koool0
0?oooolQoooo000Loooo00<0003oooooool0ooooo`;oool001coool00`000?ooooooo`3ooooo0_oo
o`007?ooo`030000oooooooo0?ooool2oooo000Loooo00<0003oooooool0ooooo`;oool001Kooooo
00000`0000Soool001coool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0<oooo000Loooo00<0003oooooool09_ooo`030000
oooooooo02Koool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo02Koool0
0`000?ooooooo`0Voooo00<0003oooooool03?ooo`007?ooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`80001@oooo00<0003oooooool0C_ooo`030000oooooooo05koool0
01coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool0
0`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?oo
ooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0
003oooooool0C_ooo`030000oooooooo05koool001coool20000D?ooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?oo
ooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1N
oooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000L
oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0
003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo0P00053oool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_oo
o`007?ooo`80001@oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?oo
ooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool000coool300001?ooo`<00006oooo00<0
003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000;oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000000Goool00`000?ooooooo`1?oooo00<0003ooooo
ool0C_ooo`030000oooooooo05koool000ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000?oooo00@0
003oooooool00003oooo00<0003oooooool00oooo`<0001?oooo00<0003oooooool0C_ooo`030000
oooooooo05koool000_oool01@000?ooooooooooo`000002oooo00D0003oooooooooool000001Ooo
o`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`002oooo`@00003
oooo00D0003oooooooooool000001Oooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`002oooo`030000oooooooo00Coool01@000?ooooooooooo`000005oooo00<0
003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000<oooo00<0003ooooo
ool00oooo`050000oooooooooooo000000Goool00`000?ooooooo`1?oooo00<0003oooooool0C_oo
o`030000oooooooo05koool000coool400000oooo`<00006oooo00<0003oooooool0Coooo`030000
oooooooo04koool00`000?ooooooo`1Noooo000Loooo0P00053oool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_oo
o`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?oo
o`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000
oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`80001@oooo00<0
003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003ooooo
ool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_oo
o`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000
oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo
05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool0
01coool20000D?ooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003ooooo
ool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Cooo
o`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000
oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo
04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo000Loooo0P00053oool00`000?ooooooo`1>oooo00<0003oooooool0G_oo
o`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?oo
o`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000
oooooooo00?oool300001?ooo`<00006oooo00<0003oooooool0Coooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo0006oooo00<0003oooooool00_ooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`000005oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?oo
ooooo`1Noooo0006oooo00<0003oooooool00_ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`000005oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1N
oooo0006oooo00<0003oooooool00_ooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`000005oooo0`0004ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000
oooooooo00;oool01@000?ooooooooooo`000002oooo00D0003oooooooooool000001Oooo`030000
oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000oooooooo
00;oool01@000?ooooooooooo`000002oooo00D0003oooooooooool000001Oooo`030000oooooooo
04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001?ooo`030000oooo000000Coool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool000001Oooo`030000oooooooo04ooool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001Oooo`800004oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000000Goool00`000?ooooooo`1?oooo00<0003oooooool0C_oo
o`030000oooooooo05koool000Koool00`000?ooooooo`03oooo0`0000Coool300001_ooo`030000
oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`80001@oooo00<0
003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003ooooo
ool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_oo
o`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000
oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo
05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool0
01coool20000D?ooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003ooooo
ool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Cooo
o`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000
oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo
04koool00`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo000Loooo0P00053oool00`000?ooooooo`1>oooo00<0003oooooool0G_oo
o`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?oo
o`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000
oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo
04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`80001@oooo00<0003oooooool0C_ooo`030000
oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo
05koool000Koool00`000?ooooooo`03oooo0`0000Coool300001_ooo`030000oooooooo04ooool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000oooooooo00;oool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool000001Oooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000oooooooo00Koool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?oo
ooooo`1Noooo0006oooo00<0003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Koool0
0`000?ooooooo`02oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000000Goool3
0000Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo0006oooo00<0003oooooool00_oo
o`@00003oooo00D0003oooooooooool000001Oooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`001?ooo`030000oooo000000Coool00`000?ooooooo`04oooo00D0
003oooooooooool000001Oooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`001Oooo`800005oooo00<0003oooooool00oooo`050000oooooooooooo000000Goool0
0`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Koool00`000?oo
ooooo`03oooo100000?oool300001_ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`007?ooo`80001@oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool0
0`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?oo
ooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0
003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0003ooooo
ool0C_ooo`030000oooooooo05koool001coool20000D?ooo`030000oooooooo04koool00`000?oo
ooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1N
oooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000L
oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0
003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0003ooooo
ool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo0P00053oool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_oo
o`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?oo
o`80001@oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0
003oooooool0C_ooo`030000oooooooo05koool000Coool500000oooo`<00004oooo0`0000Koool0
0`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Goool00`000?oo
ooooo`03oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000000Goool00`000?oo
ooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Koool00`000?ooooooo`02
oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000000Goool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Ooool01@000?ooooooooooo`000003
oooo00@0003oooooool00003oooo00<0003oooooool00oooo`<0001?oooo00<0003oooooool0C_oo
o`030000oooooooo05koool000Ooool01@000?ooooooooooo`000003oooo00@0003oooooool00003
oooo00<0003oooooool00oooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0003ooooo
ool0G_ooo`002?ooo`040000oooooooo00000oooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool000Soool0
10000?ooooooo`0000?oool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo0004oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`000005oooo00<0003ooooo
ool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo0005oooo0`0000Coool300001?oo
o`<00006oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000L
oooo0P00053oool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo
04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>oooo00<0
003oooooool0G_ooo`007?ooo`80001@oooo00<0003oooooool0C_ooo`030000oooooooo05koool0
01coool00`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool0
0`000?ooooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?oo
ooooo`1?oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?
oooo00<0003oooooool0C_ooo`030000oooooooo05koool001coool00`000?ooooooo`1?oooo00<0
003oooooool0C_ooo`030000oooooooo05koool001coool20000D?ooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?oo
ooooo`1Noooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1N
oooo000Loooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000L
oooo00<0003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo00<0
003oooooool0Coooo`030000oooooooo04koool00`000?ooooooo`1Noooo000Loooo0P00053oool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?oo
ooooo`1>oooo00<0003oooooool0G_ooo`007?ooo`030000oooooooo04ooool00`000?ooooooo`1>
oooo00<0003oooooool0G_ooo`001?ooo`D00003oooo0`0000Coool300001_ooo`030000oooooooo
04ooool00`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001Oooo`030000oooooooo00?oool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool000001Oooo`030000oooooooo04ooool0
0`000?ooooooo`1>oooo00<0003oooooool0G_ooo`001_ooo`030000oooooooo00Koool010000?oo
ooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0Coooo`030000oooooooo04koool0
0`000?ooooooo`1Noooo0007oooo00<0003oooooool01Oooo`040000oooooooo00000oooo`030000
oooooooo00?ooomC0000D?oooe<0000>oooo0007oooo00D0003oooooooooool000000oooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`3ooooo0_ooo`002?ooo`030000
oooooooo00@00003oooo00D0003oooooooooool000001Oooo`030000oooooooo0?ooool2oooo0008
oooo00@0003oooooool00006oooo00D0003oooooooooool000001Oooo`030000oooooooo0?ooool2
oooo0004oooo00D0003oooooooooool000000oooo`030000oooooooo00?oool01@000?oooooooooo
o`000005oooo00<0003oooooool0ooooo`;oool000Goool300001?ooo`@00003oooo0`000?ooool;
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-35.2944, -30.7134, 1.2269, \
1.65827}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.00234878 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .60332 m
.34127 .60332 L
.34127 .01472 L
.65873 .01472 L
.65873 .60332 L
.97619 .60332 L
s
.34127 .08684 m
.65873 .08684 L
s
.34127 .29819 m
.65873 .29819 L
s
.34127 .59018 m
.65873 .59018 L
s
gsave
.81746 .08684 -92.8438 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30.71) show
92.625 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
94.813 15.750 moveto
0.000 0.000 rmoveto
98.188 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meV) show
122.688 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .29819 -96.125 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120.69) show
99.188 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
101.375 15.750 moveto
0.000 0.000 rmoveto
104.750 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meV) show
129.250 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81746 .59018 -89.5625 -11.6563 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.3125 translate 1 -1 scale
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(245.) show
86.063 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
88.250 15.750 moveto
0.000 0.000 rmoveto
91.625 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meV) show
116.125 15.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool006;ooomK0000Hoooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?oo
ooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Q
oooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1G
oooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001R
oooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0
003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0
003oooooool0Eoooo`030000oooooooo00ooool300001?ooo`<00003oooo00D0003oooooooooool0
00001oooo`030000oooooooo00Koool01@000?ooooooooooo`000003oooo00@0003oooooooooool3
00001Oooo`030000oooooooo01Woool006;oool00`000?ooooooo`1Goooo00<0003oooooool03_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`000006oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool01@000?ooooooooooo`000003oooo00@0003oooooool00003oooo00<0
003oooooool00_ooo`030000oooooooo01Woool006;oool00`000?ooooooo`1Goooo00<0003ooooo
ool04_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`050000oooooooooooo000000?oool010000?ooooooo`0000Ooool00`000?oo
o`00000Joooo001RooooF`0001Coool010000?ooooooo`0000?oool00`000?ooooooo`05oooo00<0
003oooooool01?ooo`030000oooooooo00Koool01@000?ooooooooooo`000003oooo00<0003ooooo
ool01@0000?oool00`000?ooo`00000Joooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
013oool200000oooo`050000oooooooooooo000000Ooool00`000?ooooooo`04oooo00<0003ooooo
ool01_ooo`050000oooooooooooo000000?oool010000?ooooooo`0000?oool010000?ooooooo`00
00?oool00`000?ooooooo`0Goooo001Roooo00<0003oooooool0Eoooo`030000oooooooo01;oool0
10000?ooooooo`0000?oool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo
00Koool200000_ooo`800002oooo00@0003oooooool00003oooo00@0003oooooool00003oooo00<0
003oooooool05oooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0Boooo00@0003ooooo
ool00003oooo00<0003oooooool01_ooo`070000oooooooooooo0000oooo000000Soool010000?oo
o`00000000;oool200001?ooo`<00003oooo00D0003oooooooooool000006Oooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`0>oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000000Soool00`000?ooooooo`02oooo0P0001Woool00`000?ooooooo`03oooo00<0003ooooo
ool05_ooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0?oooo0`0000Coool300001_oo
o`D00004oooo00<0003oooooool05oooo`030000oooooooo00?oool00`000?ooooooo`0Foooo001R
oooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0
003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0
003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003ooooo
ool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003ooooo
ool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOoo
o`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eooo
o`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?oo
ooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Q
oooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1G
oooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001R
oooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0
003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0
003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003ooooo
ool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003ooooo
ool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOoo
o`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eooo
o`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool03Oooo`030000oooooooo00;oool500000oooo`<00003
oooo00@0003oooooooooool300001?ooo`<00007oooo00D0003oooooooooool000000oooo`040000
oooooooooooo0`0000Goool00`000?ooooooo`0Eoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo00goool00`000?ooooooo`03oooo00<0003oooooool00oooo`050000oooooooooooo0000
00Goool01@000?ooooooooooo`000002oooo00D0003oooooooooool000001_ooo`050000oooooooo
oooo000000?oool010000?ooooooo`0000?oool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0=oooo00<0003oooooool01?ooo`030000
oooooooo00;oool01@000?ooooooooooo`000005oooo00D0003oooooooooool000001_ooo`030000
oooooooo00Coool01@000?ooooooooooo`000003oooo00@0003oooooool00007oooo00<0003oool0
00005_ooo`00H_oooe/0000?oooo00<0003oooooool01Oooo`050000oooooooooooo000000?oool0
0`000?ooooooo`03oooo00D0003oooooooooool000000oooo`8000000oooo`000?ooo`05oooo00D0
003oooooooooool000000oooo`030000oooooooo00D00003oooo00<0003oool000005_ooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`0=oooo00<0003oooooool01Oooo`050000oooooooo
oooo000000?oool00`000?ooooooo`03oooo0P0000;oool010000?ooooooo`0000;oool200001_oo
o`050000oooooooooooo000000?oool010000?ooooooo`0000?oool010000?ooooooo`0000?oool0
0`000?ooooooo`0Coooo001Roooo00<0003oooooool0Eoooo`030000oooooooo00goool00`000?oo
ooooo`06oooo00@0003oooooool00003oooo00<0003oooooool00oooo`040000oooo000000000ooo
o`050000oooooooooooo000000Koool200000_ooo`800002oooo00@0003oooooool00003oooo00@0
003oooooool00003oooo00<0003oooooool04oooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`0;oooo00<0003oool000002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00D0003oooooooooool000001_ooo`040000oooo000000000_ooo`800004
oooo0`0000?oool01@000?ooooooooooo`00000Eoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo00coool200001?ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`000005
oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000001Ooool00`000?ooooooo`03
oooo00<0003oooooool04_ooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0=oooo00<0
003oooooool00oooo`<00004oooo0`0000Ooool300001?ooo`<0000Hoooo00<0003oooooool00ooo
o`030000oooooooo01;oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?oo
ooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Q
oooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1G
oooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001R
oooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0
003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0
003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003ooooo
ool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003ooooo
ool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOoo
o`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eooo
o`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?oo
ooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Q
oooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1G
oooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001R
oooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0
003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0
003oooooool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003ooooo
ool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003ooooo
ool0Eoooo`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOoo
o`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eooo
o`030000oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_oo
o`030000oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000
oooooooo05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo
067oool006;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo
05Ooool00`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool0
06;oool00`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool0
0`000?ooooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo067oool006;oool0
0`000?ooooooo`1Goooo00<0003oooooool0HOooo`00H_ooo`030000oooooooo05Ooool00`000?oo
ooooo`1Qoooo001Roooo00<0003oooooool0Eoooo`030000oooooooo017oool500001Oooo`030000
oooooooo00;oool300000oooo`030000oooooooo00Goool01@000?ooooooooooo`000003oooo00@0
003oooooooooool300001Oooo`030000oooooooo01coool006;oool00`000?ooooooo`1Goooo00<0
003oooooool04_ooo`030000oooooooo00Koool01@000?ooooooooooo`000003oooo00<0003ooooo
ool02?ooo`050000oooooooooooo000000?oool010000?ooooooo`0000?oool00`000?ooooooo`02
oooo00<0003oooooool07?ooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0Coooo00<0
003oooooool00_ooo`D00006oooo00<0003oooooool02?ooo`050000oooooooooooo000000?oool0
10000?ooooooo`0000Ooool00`000?ooo`00000Moooo001Roooo00<0003oooooool0Eoooo`030000
oooooooo01Coool01@000?ooooooooooo`000002oooo00<0003oooooool01Oooo`030000oooooooo
00Soool01@000?ooooooooooo`000003oooo00<0003oooooool01@0000?oool00`000?ooo`00000M
oooo001RooooF`0001Koool00`000?ooooooo`02oooo00<0003oool000000oooo`050000oooooooo
oooo000000[oool01@000?ooooooooooo`000003oooo00@0003oooooool00003oooo00@0003ooooo
ool00003oooo00<0003oooooool06_ooo`00H_ooo`030000oooooooo05Ooool00`000?ooooooo`0E
oooo00L0003oooooooooool0003oool000000oooo`@0000;oooo0P0000;oool200000_ooo`040000
oooooooo00000oooo`040000oooooooo00000oooo`030000oooooooo01[oool006;oool00`000?oo
ooooo`1Goooo00<0003oooooool05Oooo`030000oooooooo00;oool200000oooo`030000oooooooo
00coool010000?ooo`00000000;oool200001?ooo`<00003oooo00D0003oooooooooool000007?oo
o`001ooooe`0001IooooG00000Soool00=7oool300001_ooo`030000oooooooo00;oool400006ooo
o`030000oooooooo00?oool00`000?ooooooo`0Ioooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.89067, -6.26631, 1.10028, \
1.48714}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{823, 565},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 4927, 96, 1689, "Input"],
Cell[6669, 149, 107, 2, 38, "Output"],
Cell[6779, 153, 55, 1, 38, "Output"],
Cell[6837, 156, 69, 1, 39, "Output"],
Cell[6909, 159, 55, 1, 38, "Output"],
Cell[6967, 162, 70, 1, 39, "Output"],
Cell[7040, 165, 55, 1, 38, "Output"],
Cell[7098, 168, 70, 1, 39, "Output"],
Cell[7171, 171, 55, 1, 38, "Output"],
Cell[7229, 174, 63, 1, 57, "Output"],
Cell[7295, 177, 54, 1, 38, "Output"],
Cell[7352, 180, 247, 4, 51, "Message"],
Cell[7602, 186, 41876, 1335, 296, 19858, 1059, "GraphicsData", "PostScript", \
"Graphics"],
Cell[49481, 1523, 237, 4, 28, "Message"],
Cell[49721, 1529, 140, 2, 38, "Output"],

Cell[CellGroupData[{
Cell[49886, 1535, 28495, 794, 186, 10159, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[78384, 2331, 18396, 400, 186, 5190, 232, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

